@@ -3,20 +3,22 @@ from .batch import batch_fetch, with_backrefs
 from .decorators import generates
 from .exceptions import ImproperlyConfigured
 from .functions import (
-    defer_except,
-    escape_like,
-    identity,
-    primary_keys,
-    naturally_equivalent,
-    render_statement,
-    render_expression,
+    create_database,
     create_mock_engine,
+    database_exists,
+    defer_except,
+    drop_database,
+    escape_like,
+    get_columns,
+    get_declarative_base,
+    get_primary_keys,
+    identity,
     mock_engine,
+    naturally_equivalent,
+    render_expression,
+    render_statement,
     sort_query,
     table_name,
-    database_exists,
-    create_database,
-    drop_database
 )
 from .listeners import (
     coercion_listener,
@@ -53,10 +55,11 @@ from .types import (
     TSVectorType,
     URLType,
     UUIDType,
+    WeekDaysType
 )
 
 
-__version__ = '0.25.2'
+__version__ = '0.25.3'
 
 
 __all__ = (
@@ -73,12 +76,14 @@ __all__ = (
     force_instant_defaults,
     generates,
     generic_relationship,
+    get_columns,
+    get_declarative_base,
+    get_primary_keys,
     identity,
     instrumented_list,
     merge,
     mock_engine,
     naturally_equivalent,
-    primary_keys,
     proxy_dict,
     render_expression,
     render_statement,
@@ -113,4 +118,5 @@ __all__ = (
     TSVectorType,
     URLType,
     UUIDType,
+    WeekDaysType
 )
