@@ -1,4 +1,9 @@
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
 from functools import partial
+from inspect import isclass
 from operator import attrgetter
 import sqlalchemy as sa
 from sqlalchemy import inspect
@@ -9,13 +14,82 @@ from sqlalchemy.orm.query import _ColumnEntity
 from sqlalchemy.orm.util import AliasedInsp
 
 
-def primary_keys(class_):
+def get_primary_keys(mixed):
     """
-    Returns all primary keys for given declarative class.
+    Return an OrderedDict of all primary keys for given Table object,
+    declarative class or declarative class instance.
+
+    :param mixed:
+        SA Table object, SA declarative class or SA declarative class instance
+
+    ::
+
+        get_primary_keys(User)
+
+        get_primary_keys(User())
+
+        get_primary_keys(User.__table__)
+
+        get_primary_keys(User.__mapper__)
+
+        get_primary_keys(sa.orm.aliased(User))
+
+        get_primary_keys(sa.orm.alised(User.__table__))
+
+
+    .. versionchanged: 0.25.3
+        Made the function return an ordered dictionary instead of generator.
+        This change was made to support primary key aliases.
+
+        Renamed this function to 'get_primary_keys', formerly 'primary_keys'
+
+    .. seealso:: :func:`get_columns`
     """
-    for column in class_.__table__.c:
+    columns = OrderedDict()
+    for key, column in get_columns(mixed).items():
         if column.primary_key:
-            yield column
+            columns[key] = column
+    return columns
+
+
+def get_columns(mixed):
+    """
+    Return a collection of all Column objects for given SQLAlchemy
+    object.
+
+    The type of the collection depends on the type of the object to return the
+    columns from.
+
+    ::
+
+        get_columns(User)
+
+        get_columns(User())
+
+        get_columns(User.__table__)
+
+        get_columns(User.__mapper__)
+
+        get_columns(sa.orm.aliased(User))
+
+        get_columns(sa.orm.alised(User.__table__))
+
+
+    :param mixed:
+        SA Table object, SA Mapper, SA declarative class, SA declarative class
+        instance or an alias of any of these objects
+    """
+    if isinstance(mixed, sa.Table):
+        return mixed.c
+    if isinstance(mixed, sa.orm.util.AliasedClass):
+        return sa.inspect(mixed).mapper.columns
+    if isinstance(mixed, sa.sql.selectable.Alias):
+        return mixed.c
+    if isinstance(mixed, sa.orm.Mapper):
+        return mixed.columns
+    if not isclass(mixed):
+        mixed = mixed.__class__
+    return sa.inspect(mixed).columns
 
 
 def table_name(obj):
@@ -200,7 +274,7 @@ def get_expr_attr(expr, attr_name):
         return getattr(expr, attr_name)
 
 
-def declarative_base(model):
+def get_declarative_base(model):
     """
     Returns the declarative base for given model class.
 
@@ -209,7 +283,7 @@ def declarative_base(model):
     for parent in model.__bases__:
         try:
             parent.metadata
-            return declarative_base(parent)
+            return get_declarative_base(parent)
         except AttributeError:
             pass
     return model
@@ -325,8 +399,8 @@ def identity(obj_or_class):
     :param obj: SQLAlchemy declarative model object
     """
     return tuple(
-        getattr(obj_or_class, column.name)
-        for column in primary_keys(obj_or_class)
+        getattr(obj_or_class, column_key)
+        for column_key in get_primary_keys(obj_or_class).keys()
     )
 
 
